@@ -38,6 +38,11 @@ from argparse import (
 )
 from typing import Any, Dict, List, Type
 
+from rich_argparse import (
+    ArgumentDefaultsRichHelpFormatter,
+    RawDescriptionRichHelpFormatter,
+)
+
 
 # =============================================================================
 # Argparse actions
@@ -100,6 +105,19 @@ class RawDescriptionArgumentDefaultsHelpFormatter(
     pass
 
 
+class RawDescriptionArgumentDefaultsRichHelpFormatter(
+    ArgumentDefaultsRichHelpFormatter, RawDescriptionRichHelpFormatter
+):
+    """
+    Combines the features of
+
+    - :class:`RawDescriptionRichHelpFormatter` -- don't mangle the description
+    - :class:`ArgumentDefaultsRichHelpFormatter` -- print argument defaults
+    """
+
+    pass
+
+
 # =============================================================================
 # Argparse types/checkers
 # =============================================================================
